@@ -1,5 +1,5 @@
 /**
- * $Id: SimpleExpander.java,v 1.2 2006/02/11 11:21:26 afcowie Exp $
+ * $Id: SimpleExpander.java,v 1.2.2.1 2006/09/15 01:09:22 afcowie Exp $
  *
  **/
 package expander;
@@ -49,6 +49,7 @@ public class SimpleExpander {
             public boolean expanderEvent(ExpanderEvent event) {
                 if (event.isOfType(ExpanderEvent.Type.ACTIVATE)) {
                     indicator.setLabel("YES");
+                    setButtonState(expander.getExpanded());
                 }
 
                 return false;
@@ -134,6 +135,13 @@ public class SimpleExpander {
         mainWin.showAll();
     }
 
+    private void setButtonState(boolean b) {
+        if (b == true)
+            radioBtns[0].activate();
+        else
+            radioBtns[1].activate();
+    }
+
     private void setExpanderStyle() {
         if (radioBtns[0].getState()) {
             expander.setExpanded(false);
