@@ -9,14 +9,16 @@
 
 #include <jni.h>
 #include <gtk/gtk.h>
-#include "jg_jnu.h"
+#include <jg_jnu.h>
+#include "gtk_java.h"
 
+#include "org_gnu_gtk_ColorSelectionDialog.h"
 #ifdef __cplusplus
 extern "C" 
 {
 #endif
 
-GtkColorSelection * GtkColorSelectionDialog_get_colorsel (GtkColorSelectionDialog * cptr) 
+static GtkColorSelection * GtkColorSelectionDialog_get_colorsel (GtkColorSelectionDialog * cptr) 
 {
     return (GtkColorSelection*)cptr->colorsel;
 }
@@ -29,10 +31,10 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ColorSelectionDialog_getColorsel (JNI
     cls, jobject cptr) 
 {
     GtkColorSelectionDialog *cptr_g = (GtkColorSelectionDialog *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GtkColorSelectionDialog_get_colorsel (cptr_g));
+    return getGObjectHandleAndRef(env, (GObject *) GtkColorSelectionDialog_get_colorsel (cptr_g));
 }
 
-GtkButton * GtkColorSelectionDialog_get_ok_button (GtkColorSelectionDialog * cptr) 
+static GtkButton * GtkColorSelectionDialog_get_ok_button (GtkColorSelectionDialog * cptr) 
 {
     return (GtkButton*)cptr->ok_button;
 }
@@ -45,10 +47,10 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ColorSelectionDialog_getOkButton (JNI
     cls, jobject cptr) 
 {
     GtkColorSelectionDialog *cptr_g = (GtkColorSelectionDialog *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GtkColorSelectionDialog_get_ok_button (cptr_g));
+    return getGObjectHandleAndRef(env, (GObject *) GtkColorSelectionDialog_get_ok_button (cptr_g));
 }
 
-GtkButton * GtkColorSelectionDialog_get_cancel_button (GtkColorSelectionDialog * cptr) 
+static GtkButton * GtkColorSelectionDialog_get_cancel_button (GtkColorSelectionDialog * cptr) 
 {
     return (GtkButton*)cptr->cancel_button;
 }
@@ -61,10 +63,10 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ColorSelectionDialog_getCancelButton
     jclass cls, jobject cptr) 
 {
     GtkColorSelectionDialog *cptr_g = (GtkColorSelectionDialog *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GtkColorSelectionDialog_get_cancel_button (cptr_g));
+    return getGObjectHandleAndRef(env, (GObject *) GtkColorSelectionDialog_get_cancel_button (cptr_g));
 }
 
-GtkButton * GtkColorSelectionDialog_get_help_button (GtkColorSelectionDialog * cptr) 
+static GtkButton * GtkColorSelectionDialog_get_help_button (GtkColorSelectionDialog * cptr) 
 {
     return (GtkButton*)cptr->help_button;
 }
@@ -77,7 +79,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ColorSelectionDialog_getHelpButton (J
     cls, jobject cptr) 
 {
     GtkColorSelectionDialog *cptr_g = (GtkColorSelectionDialog *)getPointerFromHandle(env, cptr);
-    return getHandleFromPointer(env, GtkColorSelectionDialog_get_help_button (cptr_g));
+    return getGObjectHandleAndRef(env, (GObject *) GtkColorSelectionDialog_get_help_button (cptr_g));
 }
 
 /*
@@ -99,7 +101,7 @@ JNIEXPORT jobject JNICALL Java_org_gnu_gtk_ColorSelectionDialog_gtk_1color_1sele
     JNIEnv *env, jclass cls, jstring title) 
 {
     gchar* title_g = (gchar*)(*env)->GetStringUTFChars(env, title, 0);
-    jobject hndl = getHandleFromPointer(env, gtk_color_selection_dialog_new (title_g));
+    jobject hndl = getGObjectHandle(env, (GObject *) gtk_color_selection_dialog_new (title_g));
     (*env)->ReleaseStringUTFChars(env, title, title_g);
     return hndl;
 }
